@@ -4,13 +4,11 @@ import unittest
 
 from .GuiReceiveTest import GuiReceiveTest
 
+
 class LocalReceiveModePublicModeTest(unittest.TestCase, GuiReceiveTest):
     @classmethod
     def setUpClass(cls):
-        test_settings = {
-            "public_mode": True,
-            "receive_allow_receiver_shutdown": True
-        }
+        test_settings = {"public_mode": True, "receive_allow_receiver_shutdown": True}
         cls.gui = GuiReceiveTest.set_up(test_settings)
 
     @classmethod
@@ -18,10 +16,11 @@ class LocalReceiveModePublicModeTest(unittest.TestCase, GuiReceiveTest):
         GuiReceiveTest.tear_down()
 
     @pytest.mark.gui
-    @pytest.mark.skipif(pytest.__version__ < '2.9', reason="requires newer pytest")
+    @pytest.mark.skipif(pytest.__version__ < "2.9", reason="requires newer pytest")
     def test_gui(self):
         self.run_all_common_setup_tests()
-        self.run_all_receive_mode_tests(True, True)
+        self.run_all_receive_mode_tests(True)
+
 
 if __name__ == "__main__":
     unittest.main()
