@@ -5,13 +5,11 @@ from PyQt5 import QtCore, QtTest
 
 from .GuiShareTest import GuiShareTest
 
+
 class LocalShareModeAutoStartTimerTooShortTest(unittest.TestCase, GuiShareTest):
     @classmethod
     def setUpClass(cls):
-        test_settings = {
-            "public_mode": False,
-            "autostart_timer": True,
-        }
+        test_settings = {"public_mode": False, "autostart_timer": True}
         cls.gui = GuiShareTest.set_up(test_settings)
 
     @classmethod
@@ -19,7 +17,7 @@ class LocalShareModeAutoStartTimerTooShortTest(unittest.TestCase, GuiShareTest):
         GuiShareTest.tear_down()
 
     @pytest.mark.gui
-    @pytest.mark.skipif(pytest.__version__ < '2.9', reason="requires newer pytest")
+    @pytest.mark.skipif(pytest.__version__ < "2.9", reason="requires newer pytest")
     def test_gui(self):
         self.run_all_common_setup_tests()
         self.run_all_share_mode_setup_tests()
@@ -27,8 +25,11 @@ class LocalShareModeAutoStartTimerTooShortTest(unittest.TestCase, GuiShareTest):
         self.set_autostart_timer(self.gui.share_mode, 2)
         QtTest.QTest.qWait(3000)
         QtCore.QTimer.singleShot(4000, self.accept_dialog)
-        QtTest.QTest.mouseClick(self.gui.share_mode.server_status.server_button, QtCore.Qt.LeftButton)
+        QtTest.QTest.mouseClick(
+            self.gui.share_mode.server_status.server_button, QtCore.Qt.LeftButton
+        )
         self.assertEqual(self.gui.share_mode.server_status.status, 0)
 
+
 if __name__ == "__main__":
     unittest.main()
