@@ -8,9 +8,7 @@ from .TorGuiShareTest import TorGuiShareTest
 class ShareModeCancelSecondShareTest(unittest.TestCase, TorGuiShareTest):
     @classmethod
     def setUpClass(cls):
-        test_settings = {
-            "close_after_first_download": True
-        }
+        test_settings = {"close_after_first_download": True}
         cls.gui = TorGuiShareTest.set_up(test_settings)
 
     @classmethod
@@ -19,7 +17,7 @@ class ShareModeCancelSecondShareTest(unittest.TestCase, TorGuiShareTest):
 
     @pytest.mark.gui
     @pytest.mark.tor
-    @pytest.mark.skipif(pytest.__version__ < '2.9', reason="requires newer pytest")
+    @pytest.mark.skipif(pytest.__version__ < "2.9", reason="requires newer pytest")
     def test_gui(self):
         self.run_all_common_setup_tests()
         self.run_all_share_mode_tests(False, False)
@@ -27,5 +25,6 @@ class ShareModeCancelSecondShareTest(unittest.TestCase, TorGuiShareTest):
         self.server_is_stopped(self.gui.share_mode, False)
         self.web_server_is_stopped()
 
+
 if __name__ == "__main__":
     unittest.main()
