@@ -4,12 +4,11 @@ import unittest
 
 from .TorGuiReceiveTest import TorGuiReceiveTest
 
+
 class ReceiveModeTest(unittest.TestCase, TorGuiReceiveTest):
     @classmethod
     def setUpClass(cls):
-        test_settings = {
-            "receive_allow_receiver_shutdown": True
-        }
+        test_settings = {"receive_allow_receiver_shutdown": True}
         cls.gui = TorGuiReceiveTest.set_up(test_settings)
 
     @classmethod
@@ -18,10 +17,11 @@ class ReceiveModeTest(unittest.TestCase, TorGuiReceiveTest):
 
     @pytest.mark.gui
     @pytest.mark.tor
-    @pytest.mark.skipif(pytest.__version__ < '2.9', reason="requires newer pytest")
+    @pytest.mark.skipif(pytest.__version__ < "2.9", reason="requires newer pytest")
     def test_gui(self):
         self.run_all_common_setup_tests()
         self.run_all_receive_mode_tests(False, True)
 
+
 if __name__ == "__main__":
     unittest.main()
