@@ -4,12 +4,11 @@ import unittest
 
 from .TorGuiShareTest import TorGuiShareTest
 
+
 class ShareModeCancelTest(unittest.TestCase, TorGuiShareTest):
     @classmethod
     def setUpClass(cls):
-        test_settings = {
-           "autostart_timer": True,
-        }
+        test_settings = {"autostart_timer": True}
         cls.gui = TorGuiShareTest.set_up(test_settings)
 
     @classmethod
@@ -18,11 +17,12 @@ class ShareModeCancelTest(unittest.TestCase, TorGuiShareTest):
 
     @pytest.mark.gui
     @pytest.mark.tor
-    @pytest.mark.skipif(pytest.__version__ < '2.9', reason="requires newer pytest")
+    @pytest.mark.skipif(pytest.__version__ < "2.9", reason="requires newer pytest")
     def test_gui(self):
         self.run_all_common_setup_tests()
         self.run_all_share_mode_setup_tests()
         self.cancel_the_share(self.gui.share_mode)
 
+
 if __name__ == "__main__":
     unittest.main()
