@@ -4,13 +4,11 @@ import unittest
 
 from .TorGuiShareTest import TorGuiShareTest
 
+
 class ShareModeStealthTest(unittest.TestCase, TorGuiShareTest):
     @classmethod
     def setUpClass(cls):
-        test_settings = {
-            "use_legacy_v2_onions": True,
-            "use_stealth": True,
-        }
+        test_settings = {"use_legacy_v2_onions": True, "use_stealth": True}
         cls.gui = TorGuiShareTest.set_up(test_settings)
 
     @classmethod
@@ -19,7 +17,7 @@ class ShareModeStealthTest(unittest.TestCase, TorGuiShareTest):
 
     @pytest.mark.gui
     @pytest.mark.tor
-    @pytest.mark.skipif(pytest.__version__ < '2.9', reason="requires newer pytest")
+    @pytest.mark.skipif(pytest.__version__ < "2.9", reason="requires newer pytest")
     def test_gui(self):
         self.run_all_common_setup_tests()
         self.run_all_share_mode_setup_tests()
@@ -27,5 +25,6 @@ class ShareModeStealthTest(unittest.TestCase, TorGuiShareTest):
         self.hidserv_auth_string()
         self.copy_have_hidserv_auth_button(self.gui.share_mode)
 
+
 if __name__ == "__main__":
     unittest.main()
