@@ -4,12 +4,11 @@ import unittest
 
 from .TorGuiShareTest import TorGuiShareTest
 
+
 class ShareModeV2OnionTest(unittest.TestCase, TorGuiShareTest):
     @classmethod
     def setUpClass(cls):
-        test_settings = {
-            "use_legacy_v2_onions": True,
-        }
+        test_settings = {"use_legacy_v2_onions": True}
         cls.gui = TorGuiShareTest.set_up(test_settings)
 
     @classmethod
@@ -18,11 +17,12 @@ class ShareModeV2OnionTest(unittest.TestCase, TorGuiShareTest):
 
     @pytest.mark.gui
     @pytest.mark.tor
-    @pytest.mark.skipif(pytest.__version__ < '2.9', reason="requires newer pytest")
+    @pytest.mark.skipif(pytest.__version__ < "2.9", reason="requires newer pytest")
     def test_gui(self):
         self.run_all_common_setup_tests()
         self.run_all_share_mode_tests(False, False)
         self.have_v2_onion()
 
+
 if __name__ == "__main__":
     unittest.main()
